﻿using System;
using System.Collections.Generic;
using System.Text;
using System.IO;

namespace Mini.Controller
{
    public class MiniUtility
    {
        /// <summary>
        /// Path to the folder in which preference file is stored.
        /// </summary>
        public static string PathToPreferenceFileStorageFolder
        {
            get
            {
                string path = Environment.GetFolderPath(Environment.SpecialFolder.ApplicationData) +
                                Path.DirectorySeparatorChar + "Mini" + Path.DirectorySeparatorChar;

                if (!Directory.Exists(path))
                {
                    Directory.CreateDirectory(path);
                }

                return path;
            }
        }

        /// <summary>
        /// The path to Espresso data folder for the current user. 
        /// Creates the directory if it does not exist (this probably should
        /// not be done here).
        /// </summary>
        public static string PathToMiniDataFolder
        {
            get
            {
                string path = "";
                bool useDefaultPath = (bool)Preferences.Instance.GetProperty("UseDefaultPathToStorageFolder");

                if (useDefaultPath)
                {
                    path = Environment.GetFolderPath(Environment.SpecialFolder.ApplicationData) +
                            Path.DirectorySeparatorChar + "Mini";
                }
                else
                {
                    path = (string)Preferences.Instance.GetProperty("PathToStorageFolder");
                }

                if (!Directory.Exists(path))
                {
                    Directory.CreateDirectory(path);
                }

                return path;
            }
        }

        /// <summary>
        /// Returns the path to the folder containing the pbms and the OMR files for a given file
        /// (with a folder separator on the end). Creates the folder if it does not exist.
        /// </summary>
        /// <param name="fileName">The name of the file</param>
        /// <returns></returns>
        public static string GetPathToStorageFolder(string fileName)
        {
            string path = PathToMiniDataFolder + Path.DirectorySeparatorChar +
                fileName + Path.DirectorySeparatorChar;

            if (!Directory.Exists(path))
            {
                Directory.CreateDirectory(path);
            }

            return path;
        }
    }
}
