﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Threading;

namespace Mini.View
{
    public partial class MiniMainForm : Form
    {
        private String currentlyOpenedDocument;
        private bool inFullScreenMode;

        public MiniMainForm()
        {
            InitializeComponent();
            currentlyOpenedDocument = "";
            inFullScreenMode = false;
        }

        private void exitToolStripMenuItem_Click(object sender, EventArgs e)
        {
            this.Close();
        }

        private void openToolStripMenuItem_Click(object sender, EventArgs e)
        {
            OpenAFile();
        }

        private void fullscreenToolStripMenuItem_Click(object sender, EventArgs e)
        {
            if (fullscreenToolStripMenuItem.Checked)
            {
                ChangeViewMode(false);
            }
            else
            {
                ChangeViewMode(true);
            }
        }

        /// <summary>
        /// Closes the current document, prompts the user for a pdf and
        /// displays it if the user selects one.
        /// </summary>
        private void OpenAFile()
        {
            //Prompt user for a file
            OpenFileDialog dialog = new OpenFileDialog();
            dialog.Filter = "PDF Files|*.pdf|All files|*.*";
            dialog.FilterIndex = 1;

            //If there is a file selected, open it
            if (dialog.ShowDialog() == DialogResult.OK)
            {
                string pdfFilename = dialog.FileName;

                dialog.Dispose();

                Thread.Sleep(300);

                if (pdfFilename.Equals(currentlyOpenedDocument))
                {
                    OpenDocument(pdfFilename, true);
                }
                else
                {
                    OpenDocument(pdfFilename, false);
                    currentlyOpenedDocument = pdfFilename;
                }
            }
        }

        private void OpenDocument(string filePath, bool overWriteCache)
        {
            this.Cursor = Cursors.WaitCursor;

            //Create an empty document, register the event and open the file
            //Document d = new Document();

            bool openedDocument = false;
            ThreadStart ts = new ThreadStart(delegate()
            {
                //openedDocument = d.OpenAPdf(filePath, overWriteCache);
            });

            Thread openDocumentThread = new Thread(ts);
            openDocumentThread.Start();

            this.Invalidate();

            Application.DoEvents();
            openDocumentThread.Join();

            if (openedDocument)
            {
                ////Create auto-updatable fields
                //FieldUpdater<IPainter> painterUpdater =
                //    new FieldUpdater<IPainter>("TransitionType",
                //                               controller,
                //                               new PainterBuilder(d, controller.Menu));

                //FieldUpdater<MouseStrategy> mouseUpdater =
                //    new FieldUpdater<MouseStrategy>("ControlStrategy",
                //                                    controller,
                //                                    new MouseStrategyBuilder(controller));

                //controller.Reset();
            }

            this.Cursor = Cursors.Arrow;
        }

        private void ChangeViewMode(bool fullScreen)
        {
            if (fullScreen)
            {
                this.FormBorderStyle = FormBorderStyle.None;
                this.WindowState = FormWindowState.Maximized;
                inFullScreenMode = true;
                fullscreenToolStripMenuItem.Checked = true;
            }
            else
            {
                this.FormBorderStyle = FormBorderStyle.Sizable;
                this.WindowState = FormWindowState.Normal;
                inFullScreenMode = false;
                fullscreenToolStripMenuItem.Checked = false;
            }
        }

    }
}
